==> sui-tool-task-manager-1.4.0.tgz: package/lib/domain/task/Entities/TaskEntity.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import { Entity } from '@s-ui/domain';
export var TaskEntity = /*#__PURE__*/function (_Entity) {
  _inheritsLoose(TaskEntity, _Entity);
  function TaskEntity(_ref) {
    var config = _ref.config,
      createdAt = _ref.createdAt,
      finishedAt = _ref.finishedAt,
      id = _ref.id,
      log = _ref.log,
      name = _ref.name,
      status = _ref.status,
      updatedAt = _ref.updatedAt,
      work = _ref.work;
    return _Entity.call(this, {
      config: config,
      createdAt: createdAt,
      finishedAt: finishedAt,
      id: id,
      log: log,
      name: name,
      status: status,
      updatedAt: updatedAt,
      work: work
    }) || this;
  }
  var _proto = TaskEntity.prototype;
  _proto.markAsCompleted = function markAsCompleted() {
    this._status.setValue(this._config.get('AVAILABLE_STATUS').COMPLETED);
    this._finishedAt.set(new Date());
    this._updatedAt.set(new Date());
  };
  _proto.markAsInProgress = function markAsInProgress() {
    this._status.setValue(this._config.get('AVAILABLE_STATUS').IN_PROGRESS);
    this._updatedAt.set(new Date());
  };
  _proto.markAsError = function markAsError() {
    this._status.setValue(this._config.get('AVAILABLE_STATUS').ERROR);
    this._updatedAt.set(new Date());
  };
  _proto.hasInProgressWork = function hasInProgressWork() {
    return this._work.hasInProgressWork();
  };
  _proto.getRunnableWork = function getRunnableWork() {
    return this._work.getRunnableWork();
  };
  _proto.toJSON = function toJSON() {
    return {
      createdAt: this._createdAt.toJSON(),
      finishedAt: this._finishedAt.toJSON(),
      id: this._id.toJSON(),
      log: this._log.toJSON(),
      name: this._name.toJSON(),
      status: this._status.toJSON(),
      updatedAt: this._updatedAt.toJSON(),
      work: this._work.toJSON()
    };
  };
  return TaskEntity;
}(Entity);

==> sui-tool-task-manager-1.8.0.tgz: package/lib/domain/task/Entities/TaskEntity.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import { Entity } from '@s-ui/domain';
export var TaskEntity = /*#__PURE__*/function (_Entity) {
  _inheritsLoose(TaskEntity, _Entity);
  function TaskEntity(_ref) {
    var config = _ref.config,
      createdAt = _ref.createdAt,
      finishedAt = _ref.finishedAt,
      id = _ref.id,
      log = _ref.log,
      name = _ref.name,
      status = _ref.status,
      updatedAt = _ref.updatedAt,
      work = _ref.work;
    return _Entity.call(this, {
      config: config,
      createdAt: createdAt,
      finishedAt: finishedAt,
      id: id,
      log: log,
      name: name,
      status: status,
      updatedAt: updatedAt,
      work: work
    }) || this;
  }
  var _proto = TaskEntity.prototype;
  _proto.markAsCompleted = function markAsCompleted() {
    this._status.setCompleted();
    this._finishedAt.setNow();
    this._updatedAt.setNow();
  };
  _proto.markAsInProgress = function markAsInProgress() {
    this._status.setInProgress();
    this._updatedAt.setNow();
  };
  _proto.markAsError = function markAsError() {
    this._status.setError();
    this._updatedAt.setNow();
  };
  _proto.hasInProgressWork = function hasInProgressWork() {
    return this._work.hasInProgressWork();
  };
  _proto.getRunnableWork = function getRunnableWork() {
    return this._work.getRunnableWork();
  };
  _proto.toJSON = function toJSON() {
    return {
      createdAt: this._createdAt.toJSON(),
      finishedAt: this._finishedAt.toJSON(),
      id: this._id.toJSON(),
      log: this._log.toJSON(),
      name: this._name.toJSON(),
      status: this._status.toJSON(),
      updatedAt: this._updatedAt.toJSON(),
      work: this._work.toJSON()
    };
  };
  return TaskEntity;
}(Entity);
